# Microsoft Health Intelligence Machine Learning Toolbox

## Overview

This toolbox aims at providing low-level and high-level building blocks for Machine Learning / AI researchers and
practitioners. It helps to simplify and streamline work on deep learning models for healthcare and life sciences,
by providing tested components (data loaders, pre-processing), and deep learning models.

## Installation

You can install the latest version from `pypi` via 

```
pip install hi-ml
```

## Documentation

The detailed package documentation, with examples and API reference, is on 
[readthedocs](https://hi-ml.readthedocs.io/en/latest/).

## Getting started

Examples that illustrate the use of the `hi-ml` toolbox can be found on 
[readthedocs](https://hi-ml.readthedocs.io/en/latest/).

## Changelog

A changelog is [maintained on Github](https://github.com/microsoft/hi-ml/blob/main/CHANGELOG.md)

## Links

* Github [https://github.com/microsoft/hi-ml](https://github.com/microsoft/hi-ml)
* Project InnerEye [http://aka.ms/InnerEye](http://aka.ms/InnerEye)
